This is a **ACE editor widget** for for `YAFOWIL 
<http://pypi.python.org/pypi/yafowil>`_ 

- `ACE Editor <https://ace.c9.io>`_
- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#ace>`_
- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.ace/index.html>`_

Current included version of ACE editor is
`v1.4.13 <https://github.com/ajaxorg/ace-builds/releases/tag/v1.4.13>`_


Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/conestack/yafowil.widget.ace>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Robert Niederrreiter

- Georg Bernhard

- Lena Daxenbichler
